require './lib/studio_game/player'
require './lib/studio_game/treasure_trove'

module StudioGame
describe Player do
  before do
    @initial_health = 150
    @player = Player.new("larry", @initial_health)
  end

  it "has a capitalized name" do
    expect(@player.name).to eq("Larry")
  end

  it "has an initial health" do
    expect(@player.health).to eq(150)
  end

  it "has a string representation" do
    expect(@player.to_s).to eq("I'm Larry with a health of 150 and a score of 150")
  end

  it "computes a score as the sum of its health and points" do
    @player.found_treasures(Treasure.new(:hammer, 50))
    expect(@player.score).to eq(200)
  end

  it "increases health by 15 when w00ted" do
    @player.w00t

    expect(@player.health).to eq(165)
  end

  it "decreases health by 10 when blammed" do
    @player.blam

    expect(@player.health).to eq(140)
  end

  it "computes points as the sum of all treasure points" do
    @player.points.should == 0

    @player.found_treasures(Treasure.new(:hammer, 50))

    @player.points.should == 50

    @player.found_treasures(Treasure.new(:crowbar, 400))

    @player.points.should == 450

    @player.found_treasures(Treasure.new(:hammer, 50))

    @player.points.should == 500
  end

  it "yields each found treasure and its total points" do
  @player.found_treasures(Treasure.new(:skillet, 100))
  @player.found_treasures(Treasure.new(:skillet, 100))
  @player.found_treasures(Treasure.new(:hammer, 50))
  @player.found_treasures(Treasure.new(:bottle, 5))
  @player.found_treasures(Treasure.new(:bottle, 5))
  @player.found_treasures(Treasure.new(:bottle, 5))
  @player.found_treasures(Treasure.new(:bottle, 5))
  @player.found_treasures(Treasure.new(:bottle, 5))

  yielded = []
  @player.each_found_treasure do |treasure|
    yielded << treasure
  end

  yielded.should == [
    Treasure.new(:skillet, 200),
    Treasure.new(:hammer, 50),
    Treasure.new(:bottle, 25)
 ]
 end

  context "with a health greater than 100" do
    before do
      @player = Player.new("larry", 150)
    end

    it "is a strong player" do
      expect(@player.strong?).to eq(true)
    end
  end
end
end
